@@ -29,6 +29,8 @@ Keys::Keys() {
     }
 
     (*this).tmpString = (String *)NULL;
+    (*this).emptyString = new String;
+    *((*this).emptyString) = ""; // stay empty
 }
 
 
@@ -47,6 +49,8 @@ Keys::Keys(const Keys &keys) {
     }
 
     (*this).tmpString = (String *)NULL;
+    (*this).emptyString = new String;
+    *((*this).emptyString) = ""; // stay empty
 
     set(keys);
 }
@@ -93,6 +97,10 @@ bool Keys::clear() {
         delete (*this).tmpString;
         (*this).tmpString = (String *)NULL;
     }
+    if ((*this).emptyString != (String *)NULL) {
+        delete (*this).emptyString;
+        (*this).emptyString = (String *)NULL;
+    }
 
     return true;
 }
@@ -103,24 +111,48 @@ bool Keys::clear() {
     @return String object
  */
 String& Keys::operator [] (const String &key) {
+    if ((*this).isKeyExist(key) == false) {
+        (*this).addKey(key, "");
+    }
     return (*this).getValue(key.c_str());
 }
 
 
+/*! Get an element that have match key.
+    @param key  key of object
+    @return String object
+ */
+const String& Keys::operator [] (const String &key) const {
+    return (const String&)(*this).getValue(key.c_str());
+}
+
+
 /*! Get an element that have match key.
     @param key  key of object
     @return String object
  */
 String& Keys::operator [] (const char *key) {
+    if ((*this).isKeyExist(key) == false) {
+        (*this).addKey(key, "");
+    }
     return (*this).getValue(key);
 }
 
 
+/*! Get an element that have match key.
+    @param key  key of object
+    @return String object
+ */
+const String& Keys::operator [] (const char *key) const {
+    return (const String&)(*this).getValue(key);
+}
+
+
 /*! Get value of an element that have match key.
     @param key  key of object
     @return Keys object
  */
-String& Keys::getValue(const String &key) {
+String& Keys::getValue(const String &key) const {
     return (*this).getValue(key.c_str());
 }
 
@@ -129,7 +161,7 @@ String& Keys::getValue(const String &key) {
     @param key  key of object
     @return Keys object
  */
-String& Keys::getValue(const char *key) {
+String& Keys::getValue(const char *key) const {
     Element *element;
     bool found;
     int start;
@@ -142,29 +174,33 @@ String& Keys::getValue(const char *key) {
 
     found = false;
     start = b64(key[0]);
-    do {
-        if (0 < (*this).nElementTotal[start]) {
-            element = (*this).pElement[start][(*this).nElementStart[start]];
-            while (element != NULL && element->key != NULL) {
-                int cmp;
-                cmp = strcmp(key, element->key);
-                if (cmp == 0) {
-                    // found!
-                    found = true;
-                    break;
-                } else if (cmp < 0) {
-                    // small
-                    if (element->small == -1) break;
-                    element = (*this).pElement[start][element->small];
-                } else {
-                    // big
-                    if (element->big == -1) break;
-                    element = (*this).pElement[start][element->big];
-                }
+    if (0 < (*this).nElementTotal[start]) {
+        element = (*this).pElement[start][(*this).nElementStart[start]];
+        while (element != NULL && element->key != NULL) {
+            int cmp;
+            cmp = strcmp(key, element->key);
+            if (cmp == 0) {
+                // found!
+                found = true;
+                break;
+            } else if (cmp < 0) {
+                // small
+                if (element->small == -1) break;
+                element = (*this).pElement[start][element->small];
+            } else {
+                // big
+                if (element->big == -1) break;
+                element = (*this).pElement[start][element->big];
             }
         }
-    } while (found == false && (*this).addKey(key) == true);
+    }
 
+    if (found == false) {
+        if ((*((*this).emptyString)).c_str()[0] != '\0') {
+            *((*this).emptyString) = "";
+        }
+        return *((*this).emptyString);
+    }
     return *((*element).value);
 }
 
@@ -224,19 +260,19 @@ const char* Keys::read(const char *key) const {
 /*! Check the existance of key.
     @param key  key of object
     @retval true  key exist
-    @retval false key exist
+    @retval false key not exist
  */
-bool Keys::isKey(const String &key) const {
-    return isKey(key.c_str());
+bool Keys::isKeyExist(const String &key) const {
+    return isKeyExist(key.c_str());
 }
 
 
 /*! Check the existance of key.
     @param key  key of object
     @retval true  key exist
-    @retval false key exist
+    @retval false key not exist
  */
-bool Keys::isKey(const char *key) const {
+bool Keys::isKeyExist(const char *key) const {
     bool found;
     Element *element;
 
