@@ -186,7 +186,7 @@ int dtoa_lang(char *buf, double value, int figure, const char *lang) {
     if (figure < 0 || 16 < figure) figure = 2;
 
     /* 12345.678 */
-    ::sprintf(big, "%.*f", figure, value);
+    ::snprintf(big, sizeof(big), "%.*f", figure, value);
     p = strchr(big, '.');
     if (p) {
         strcpy(small, p+1);
