@@ -9,12 +9,12 @@
 
 namespace apolloron {
 
-#define GB18030_UTF8_TABLE_MAX 2323
+#define GB18030_UTF8_TABLE_MAX 8678
 
 typedef struct {
     const char *gb18030;
     const char *utf8;
-    int count;
+    unsigned char count;
 } T_GB18030_UTF8;
 
 extern const T_GB18030_UTF8 gb18030_utf8[GB18030_UTF8_TABLE_MAX];
